'use strict';

angular.module('app')
    .controller('CharacterDetailCtrl', function ($scope, $stateParams, $ionicLoading, $ionicNavBarDelegate, $ionicScrollDelegate, $ionicPopup, $state, BungieClient, CharacterService) {
        $ionicLoading.show({
            template: '<i class="ghost-loader"></i> Loading'
        });

        $scope.characterTab = 'gear';

        $scope.itemLink = function(name, id) {
            var confirmPopup = $ionicPopup.confirm({
                title: name,
                template: 'Visit DestinyDB for more information on this item? (will launch browser)'
            });
            confirmPopup.then(function (res) {
                if (res) {
                    window.open('http://www.destinydb.com/items/' + id, '_system');
                }
            });
        };

        $scope.toggleCharacterTab = function(tab) {
            if ($scope.characterTab != tab) {
                $ionicScrollDelegate.scrollTop();
                $scope.characterTab = tab;
            }
        };

        CharacterService.findCharacter($stateParams.platform, $stateParams.memberId, $stateParams.characterId)
            .then(function(result) {
                $scope.character = result.character;
                $scope.definitions = result.definitions;
                $scope.displayName = result.memberDetails.displayName;

                return BungieClient.findCharacterProgression($stateParams.platform, $stateParams.memberId, $stateParams.characterId);
            }, function() {
                $state.go('error', { error: 'network' });
            })
            .then(function(result) {
                $scope.progressions = CharacterService.filterProgressions(
                    result.getData('progressions'),
                    result.getDefinitions()
                );

                return BungieClient.findCharacterInventory($stateParams.platform, $stateParams.memberId, $stateParams.characterId);
            }, function() {
                $state.go('error', { error: 'network' });
            })
            .then(function(result) {
                $scope.equippable = CharacterService.filterEquippable(
                    result.getData('buckets').Equippable,
                    result.getDefinitions()
                );
                $scope.currencies = CharacterService.filterCurrencies(
                    $scope.progressions,
                    result.getData('currencies'),
                    result.getDefinitions()
                );

                return BungieClient.findCharacterActivities($stateParams.platform, $stateParams.memberId, $stateParams.characterId);
            }, function() {
                $state.go('error', { error: 'network' });
            })
            .then(function(result) {
                $scope.activities = CharacterService.filterWeeklyActivities(
                    result.getData('activities'),
                    result.getDefinitions()
                );

                $ionicLoading.hide();
                $ionicNavBarDelegate.title($scope.displayName);

            }, function() {
                $state.go('error', { error: 'network' });
            });
    });
