'use strict';

angular.module('app')
    .controller('CharacterListCtrl', function ($scope, $stateParams, $ionicLoading, $ionicPopup, $state, BungieClient) {
        $ionicLoading.show({
            template: '<i class="ghost-loader"></i> Loading'
        });

        $scope.$on('$ionicView.beforeEnter', function() {
            BungieClient.findCharacters($stateParams.platform, $stateParams.memberId)
                .then(function (result) {
                    $scope.platform = $stateParams.platform;
                    $scope.memberId = $stateParams.memberId;

                    $scope.definitions = result.getDefinitions();

                    $scope.characters = result.getData('characters');
                    $scope.displayName = result.getData('memberDetails').displayName;
                    $scope.inventory = result.getData()['inventory'];
                    $scope.grimoireScore = result.getData()['grimoireScore'];

                    $ionicLoading.hide();
                }, function (error) {
                    $ionicLoading.hide();

                    if (error.bungieSearchInvalid) {
                        $ionicPopup.show({
                            title: 'Oops, an error occured!',
                            subTitle: "Bungie search shows you as having an account on this platform but we can't find it." +
                            "This is an error with Bungie's API and we <strong>can not</strong> fix it. This profile will continue " +
                            "to show on recent searches until Bungie removes it from their search API.",
                            buttons: [
                                {
                                    text: 'Okay, take me home',
                                    type: 'button-positive',
                                    onTap: function () {
                                        $state.go('home');
                                    }
                                }
                            ]
                        });
                    } else {
                        $state.go('error', { error: 'network' });
                    }
                });
        });
    });
